(clojars-repo-only! {:keys [input-file output-file]
:or {input-file "pom.xml" output-file "pom.xml"}})(set-patch-version! {:keys [input-file output-file patch]
:or {input-file "pom.xml" output-file "pom.xml"}
:as opts})(tree-edit zipper matcher)Take a zipper, a function that matches a pattern in the tree, and a function that edits the current location in the tree. Examine the tree nodes in depth-first order, determine whether the matcher matches, and if so apply the editor.
Take a zipper, a function that matches a pattern in the tree, and a function that edits the current location in the tree. Examine the tree nodes in depth-first order, determine whether the matcher matches, and if so apply the editor.
(tree-editor zipper matcher editor)Take a zipper, a function that matches a pattern in the tree, and a function that edits the current location in the tree. Examine the tree nodes in depth-first order, determine whether the matcher matches, and if so apply the editor.
Take a zipper, a function that matches a pattern in the tree, and a function that edits the current location in the tree. Examine the tree nodes in depth-first order, determine whether the matcher matches, and if so apply the editor.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |